@@ -591,7 +591,7 @@ class BaseProject:
             dataformats_without_N = dataformats.replace("N","")
             for i in range(n_data):
                 self.project_logger.add_image(
-                    f"sample_images/image_{i}_label_{labels_to_show[i]}",
+                    "sample_images/image_{}_label_{}".format(i,labels_to_show[i]),
                     imgs_to_show[i],
                     dataformats=dataformats_without_N
                 )
